# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataLakeAnalyticsCatalogCredentialDeleteParameters(Model):
    """Data Lake Analytics catalog credential deletion parameters.

    :param password: the current password for the credential and user with
     access to the data source. This is required if the requester is not the
     account owner.
    :type password: str
    """

    _attribute_map = {
        'password': {'key': 'password', 'type': 'str'},
    }

    def __init__(self, password=None):
        self.password = password
